package io.example.barometer2;

import android.content.Context;
import android.hardware.Sensor;
import android.hardware.SensorEvent;
import android.hardware.SensorEventListener;
import android.hardware.SensorManager;

import androidx.annotation.NonNull;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;

/** Barometer2Plugin */
public class Barometer2Plugin implements FlutterPlugin, MethodCallHandler, SensorEventListener {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private MethodChannel channel;
  private Context mContext;
  private SensorManager mSensorManager;
  private Sensor mBarometer;
  private float barometerReading;

  @Override
  public void onAttachedToEngine( @NonNull FlutterPluginBinding flutterPluginBinding) {
    mContext = flutterPluginBinding.getApplicationContext();
    channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "barometer2");
    channel.setMethodCallHandler(this);
    initBarometer();
  }

  void initBarometer() {
    mSensorManager = (SensorManager) mContext.getSystemService(Context.SENSOR_SERVICE);
    mBarometer = mSensorManager.getDefaultSensor(Sensor.TYPE_PRESSURE);
    mSensorManager.registerListener(this, mBarometer, Sensor.TYPE_PRESSURE);
  }
  double getBarometerReading() {
    System.out.println("getBarometerReading CALLED " + barometerReading);
    return barometerReading;
  }
  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
    if (call.method.equals("getPlatformVersion")) {
      result.success("Android " + android.os.Build.VERSION.RELEASE);
    } else if(call.method.equals("getReading")){
      result.success(getBarometerReading());
    }else{
      result.notImplemented();
    }
  }

  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    channel.setMethodCallHandler(null);
  }

  @Override
  public void onSensorChanged(SensorEvent sensorEvent) {
    System.out.println("onSensorChanged CALLED " + sensorEvent.values.length);
    barometerReading = sensorEvent.values[0];
  }

  @Override
  public void onAccuracyChanged(Sensor sensor, int i) {

  }
}
